@@ -7,5 +7,5 @@
 
 from .ui.phase_plane_widget import PhasePlaneWidget
 from .ui.storage_widget import StorageWidget
-from .ui.head_widget import HeadWidget, HeadWidgetBase, HeadWidgetConfig
-from .ui.ts_widget import TimeSeriesWidget
+from .ui.head_widget import HeadBrowser, HeadWidget, HeadWidgetConfig
+from .ui.ts_widget import TimeSeriesWidget, TimeSeriesBrowser
