@@ -18,8 +18,10 @@ class DriveWidget(ipywidgets.VBox, TVBWidget):
     PARENT_DIR = '..'
     DIR_ICON = '\U0001F4C1'
 
-    def __init__(self, **kwargs):
+    def __init__(self, collab=None, folder=None, **kwargs):
         TVBWidget.__init__(self, **kwargs)
+        self.collab = collab
+        self.folder = folder
         bearer_token = get_current_token()
         self.client = ebrains_drive.connect(token=bearer_token)
 
@@ -28,10 +30,10 @@ class DriveWidget(ipywidgets.VBox, TVBWidget):
         except Exception:
             self.logger.error("Could not retrieve Repos from EBRAINS Drive!")
             all_repos = []
-        dropdown_options = [(repo.name, repo) for repo in all_repos]
+        dropdown_options = {repo.name: repo for repo in all_repos}
 
         layout = ipywidgets.Layout(width='400px')
-        self.repos_dropdown = ipywidgets.Dropdown(description='Repository', value=None,
+        self.repos_dropdown = ipywidgets.Dropdown(description='Repository', value=dropdown_options.get(self.collab),
                                                   options=dropdown_options, layout=layout)
         self.files_list = ipywidgets.Select(description='Files', value=None, disabled=False, layout=layout)
 
@@ -41,6 +43,11 @@ class DriveWidget(ipywidgets.VBox, TVBWidget):
         self._parent_dir = None
         self._map_names_to_files = dict()
 
+        if self.collab:
+            self.select_repo(None, folder=self.folder)
+            if self.collab not in list(dropdown_options):
+                self.logger.warning(f"Could not find the Collab: {self.collab}. You can manually browse for it.")
+
         ipywidgets.VBox.__init__(self, [self.repos_dropdown, self.files_list], **kwargs)
 
     def get_chosen_repo(self):
@@ -57,33 +64,42 @@ class DriveWidget(ipywidgets.VBox, TVBWidget):
         file_obj = repo_obj.get_file(self.get_selected_file_path())
         return file_obj.get_content()
 
-    def select_repo(self, _):
-        self.update_files_for_chosen_dir(self.ROOT)
+    def select_repo(self, _, folder=None):
+        if folder is None:
+            folder = self.ROOT
+        if not folder.startswith(self.ROOT):
+            folder = self.ROOT + folder
+        self.update_files_for_chosen_dir(folder)
 
     def select_dir(self, _):
         current_selection = self._map_names_to_files.get(self.files_list.value)
         if not current_selection or not current_selection.isdir:
             return
-        self.update_files_for_chosen_dir(self.ROOT + current_selection.name)
+        self.update_files_for_chosen_dir(current_selection.path)
 
     def update_files_for_chosen_dir(self, selected_dir):
         self.files_list.unobserve(self.select_dir, names='value')
-
-        selected_repo = self.get_chosen_repo()
-        self.logger.debug("Update Files called with {} and {}".format(selected_repo, selected_dir))
-        self._gather_files(selected_repo, selected_dir)
-        self.files_list.options = list(self._map_names_to_files.keys())
-        self.files_list.value = None
-
-        self.files_list.observe(self.select_dir, names='value')
+        try:
+            selected_repo = self.get_chosen_repo()
+            self.logger.debug("Update Files called with {} and {}".format(selected_repo, selected_dir))
+            self._gather_files(selected_repo, selected_dir)
+            self.files_list.options = list(self._map_names_to_files.keys())
+            self.files_list.value = None
+        except Exception as e:
+            raise e
+        finally:
+            self.files_list.observe(self.select_dir, names='value')
 
     def _gather_files(self, repo, sub_folder):
         dir_icon = self.DIR_ICON
-        self._map_names_to_files = {self.PARENT_DIR: self._parent_dir}
 
         try:
             dir_obj = repo.get_dir(sub_folder)
-            self._parent_dir = repo.get_dir(os.path.dirname(dir_obj.path))
+            if sub_folder == self.ROOT:
+                self._parent_dir = None
+            else:
+                self._parent_dir = repo.get_dir(os.path.dirname(dir_obj.path))
+            self._map_names_to_files = {self.PARENT_DIR: self._parent_dir}
 
             files_in_repository = dir_obj.ls(force_refresh=True)
 
